@@ -17,8 +17,8 @@
   
   #library.dynam("cairoDevice", pkgname, libname)
   if (!.C("loadGTK", success = logical(1), PACKAGE="cairoDevice")$success)
-    packageStartupMessage("Note: R session is headless; Cairo device not initialized")
-
+      message("R session is headless; GTK+ not initialized.")
+  
   # register device as being interactive
   deviceIsInteractive("Cairo")
 }
@@ -27,8 +27,8 @@
 {
     devices <- dev.list()
     gtk.devices <- devices[names(devices)=="Cairo"]
-    if(length(gtk.devices) > 0) {
-        dev.off(gtk.devices)
+    for (dev in gtk.devices) {
+        dev.off(dev)
     }
 }
 
@@ -51,7 +51,7 @@
            gtk_path <- .windows_gtk_path()
            ## unzip does this, but we want to see any warnings
            dir.create(gtk_path, recursive = TRUE) 
-           unzip(path, exdir = gtk_path)
+           utils::unzip(path, exdir = gtk_path)
          }
          )
 
@@ -76,11 +76,12 @@
         message("Please install ", dep_name, " from ", dep_url)
         return()
       }
-      choice <- menu(paste(c("Install", "Do not install"), dep_name), T, 
-                     paste("Need", dep_name, "? (Restart R after installing)"))
+      choice <- utils::menu(paste(c("Install", "Do not install"), dep_name), T, 
+                            paste("Need", dep_name,
+                                  "? (Restart R after installing)"))
       if (choice == 1) {
         path <- file.path(tempdir(), basename(sub("\\?.*", "", dep_url)))
-        if (download.file(dep_url, path, mode="wb") > 0)
+        if (utils::download.file(dep_url, path, mode="wb") > 0)
           stop("Failed to download ", dep_name)
         installer(path)
       }
